==> zio-aws-neptune_2.12-5.20.37.1-sources.jar: zio/aws/neptune/model/package.scala <==
package zio.aws.neptune
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.neptune.model.primitives.GlobalClusterIdentifier.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    type BooleanOptional = Boolean
    type DoubleOptional = Double
    object GlobalClusterIdentifier extends Subtype[String]
    type GlobalClusterIdentifier =
      zio.aws.neptune.model.primitives.GlobalClusterIdentifier.Type
    type Integer = Int
    type IntegerOptional = Int
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.neptune.model.primitives.TStamp.Type
  }
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.neptune.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type DBClusterEndpointList = List[zio.aws.neptune.model.DBClusterEndpoint]
  type DBClusterList = List[zio.aws.neptune.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.neptune.model.DBClusterMember]
  type DBClusterOptionGroupMemberships =
    List[zio.aws.neptune.model.DBClusterOptionGroupStatus]
  type DBClusterParameterGroupList =
    List[zio.aws.neptune.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.neptune.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.neptune.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.neptune.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.neptune.model.DBEngineVersion]
  type DBInstanceList = List[zio.aws.neptune.model.DBInstance]
  type DBInstanceStatusInfoList =
    List[zio.aws.neptune.model.DBInstanceStatusInfo]
  type DBParameterGroupList = List[zio.aws.neptune.model.DBParameterGroup]
  type DBParameterGroupStatusList =
    List[zio.aws.neptune.model.DBParameterGroupStatus]
  type DBSecurityGroupMembershipList =
    List[zio.aws.neptune.model.DBSecurityGroupMembership]
  type DBSecurityGroupNameList = List[String]
  type DBSubnetGroups = List[zio.aws.neptune.model.DBSubnetGroup]
  type DomainMembershipList = List[zio.aws.neptune.model.DomainMembership]
  type DoubleRangeList = List[zio.aws.neptune.model.DoubleRange]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.neptune.model.EventCategoriesMap]
  type EventList = List[zio.aws.neptune.model.Event]
  type EventSubscriptionsList = List[zio.aws.neptune.model.EventSubscription]
  type FilterList = List[zio.aws.neptune.model.Filter]
  type FilterValueList = List[String]
  type GlobalClusterList = List[zio.aws.neptune.model.GlobalCluster]
  type GlobalClusterMemberList = List[zio.aws.neptune.model.GlobalClusterMember]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type OptionGroupMembershipList =
    List[zio.aws.neptune.model.OptionGroupMembership]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.neptune.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.neptune.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.neptune.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.neptune.model.ResourcePendingMaintenanceActions]
  type RangeList = List[zio.aws.neptune.model.Range]
  type ReadReplicaDBClusterIdentifierList = List[String]
  type ReadReplicaDBInstanceIdentifierList = List[String]
  type ReadReplicaIdentifierList = List[String]
  type ReadersArnList = List[String]
  type SourceIdsList = List[String]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.neptune.model.Subnet]
  type SupportedCharacterSetsList = List[zio.aws.neptune.model.CharacterSet]
  type SupportedTimezonesList = List[zio.aws.neptune.model.Timezone]
  type TagList = List[zio.aws.neptune.model.Tag]
  type ValidStorageOptionsList = List[zio.aws.neptune.model.ValidStorageOptions]
  type ValidUpgradeTargetList = List[zio.aws.neptune.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.neptune.model.VpcSecurityGroupMembership]
}

==> zio-aws-neptune_2.13-5.17.201.2-sources.jar: zio/aws/neptune/model/package.scala <==
package zio.aws.neptune
import zio.prelude.Subtype
import java.time.Instant
import zio.aws.neptune.model.primitives.TStamp.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    type BooleanOptional = Boolean
    type DoubleOptional = Double
    type Integer = Int
    type IntegerOptional = Int
    object TStamp extends Subtype[Instant]
    type TStamp = zio.aws.neptune.model.primitives.TStamp.Type
  }
  type AttributeValueList = List[String]
  type AvailabilityZoneList = List[zio.aws.neptune.model.AvailabilityZone]
  type AvailabilityZones = List[String]
  type DBClusterEndpointList = List[zio.aws.neptune.model.DBClusterEndpoint]
  type DBClusterList = List[zio.aws.neptune.model.DBCluster]
  type DBClusterMemberList = List[zio.aws.neptune.model.DBClusterMember]
  type DBClusterOptionGroupMemberships =
    List[zio.aws.neptune.model.DBClusterOptionGroupStatus]
  type DBClusterParameterGroupList =
    List[zio.aws.neptune.model.DBClusterParameterGroup]
  type DBClusterRoles = List[zio.aws.neptune.model.DBClusterRole]
  type DBClusterSnapshotAttributeList =
    List[zio.aws.neptune.model.DBClusterSnapshotAttribute]
  type DBClusterSnapshotList = List[zio.aws.neptune.model.DBClusterSnapshot]
  type DBEngineVersionList = List[zio.aws.neptune.model.DBEngineVersion]
  type DBInstanceList = List[zio.aws.neptune.model.DBInstance]
  type DBInstanceStatusInfoList =
    List[zio.aws.neptune.model.DBInstanceStatusInfo]
  type DBParameterGroupList = List[zio.aws.neptune.model.DBParameterGroup]
  type DBParameterGroupStatusList =
    List[zio.aws.neptune.model.DBParameterGroupStatus]
  type DBSecurityGroupMembershipList =
    List[zio.aws.neptune.model.DBSecurityGroupMembership]
  type DBSecurityGroupNameList = List[String]
  type DBSubnetGroups = List[zio.aws.neptune.model.DBSubnetGroup]
  type DomainMembershipList = List[zio.aws.neptune.model.DomainMembership]
  type DoubleRangeList = List[zio.aws.neptune.model.DoubleRange]
  type EventCategoriesList = List[String]
  type EventCategoriesMapList = List[zio.aws.neptune.model.EventCategoriesMap]
  type EventList = List[zio.aws.neptune.model.Event]
  type EventSubscriptionsList = List[zio.aws.neptune.model.EventSubscription]
  type FilterList = List[zio.aws.neptune.model.Filter]
  type FilterValueList = List[String]
  type KeyList = List[String]
  type LogTypeList = List[String]
  type OptionGroupMembershipList =
    List[zio.aws.neptune.model.OptionGroupMembership]
  type OrderableDBInstanceOptionsList =
    List[zio.aws.neptune.model.OrderableDBInstanceOption]
  type ParametersList = List[zio.aws.neptune.model.Parameter]
  type PendingMaintenanceActionDetails =
    List[zio.aws.neptune.model.PendingMaintenanceAction]
  type PendingMaintenanceActions =
    List[zio.aws.neptune.model.ResourcePendingMaintenanceActions]
  type RangeList = List[zio.aws.neptune.model.Range]
  type ReadReplicaDBClusterIdentifierList = List[String]
  type ReadReplicaDBInstanceIdentifierList = List[String]
  type ReadReplicaIdentifierList = List[String]
  type SourceIdsList = List[String]
  type StringList = List[String]
  type SubnetIdentifierList = List[String]
  type SubnetList = List[zio.aws.neptune.model.Subnet]
  type SupportedCharacterSetsList = List[zio.aws.neptune.model.CharacterSet]
  type SupportedTimezonesList = List[zio.aws.neptune.model.Timezone]
  type TagList = List[zio.aws.neptune.model.Tag]
  type ValidStorageOptionsList = List[zio.aws.neptune.model.ValidStorageOptions]
  type ValidUpgradeTargetList = List[zio.aws.neptune.model.UpgradeTarget]
  type VpcSecurityGroupIdList = List[String]
  type VpcSecurityGroupMembershipList =
    List[zio.aws.neptune.model.VpcSecurityGroupMembership]
}
